light

package
v0.0.0-...-bfe5d0e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 4, 2022 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Colour

type Colour interface {
	Light
	// Set Colour will update the device's colour
	SetColour(ctx context.Context, c color.Color) error
}

Colour represents a light device that can configure the light's colour.

type Dimmer

type Dimmer interface {
	Light
	// SetBrightness allows you to set the brightness
	// from a percentage of 0.0 to 100.0
	SetBrightness(ctx context.Context, percentage float64) error
}

Dimmer represents a light that is dimmable

type EmbedableLight

type EmbedableLight struct{}

EmbedableLight must be used to be embeded into the concrete type so the Light interface is satisified

type Light

type Light interface {
	device.Device
	// contains filtered or unexported methods
}

Light represents a IoT device that is lightbulb.

Jump to