outlet

package
v0.0.0-...-bfe5d0e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 4, 2022 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type EmbedableMonitor

type EmbedableMonitor struct{}

EmbedableMonitor must be embeded into the concrete struct type in order for the type to adhere to the Monitor interface

type EmbedableOutlet

type EmbedableOutlet struct{}

EmbedableOutlet must be used in concrete types for for the concrete type to implement the Outlet interface

type Monitor

type Monitor interface {
	device.MonitoredDevice
	// contains filtered or unexported methods
}

Monitor represents an outlet that can track its energy usage

type Outlet

type Outlet interface {
	device.Device
	// contains filtered or unexported methods
}

Outlet represents a device that be controlled

Jump to