Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Colour ¶
type Colour interface {
Light
// Set Colour will update the device's colour
SetColour(ctx context.Context, c color.Color) error
}
Colour represents a light device that can configure the light's colour.
type Dimmer ¶
type Dimmer interface {
Light
// SetBrightness allows you to set the brightness
// from a percentage of 0.0 to 100.0
SetBrightness(ctx context.Context, percentage float64) error
}
Dimmer represents a light that is dimmable
type EmbedableLight ¶
type EmbedableLight struct{}
EmbedableLight must be used to be embeded into the concrete type so the Light interface is satisified
Click to show internal directories.
Click to hide internal directories.