Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EmbedableMonitor ¶
type EmbedableMonitor struct{}
EmbedableMonitor must be embeded into the concrete struct type in order for the type to adhere to the Monitor interface
type EmbedableOutlet ¶
type EmbedableOutlet struct{}
EmbedableOutlet must be used in concrete types for for the concrete type to implement the Outlet interface
type Monitor ¶
type Monitor interface {
device.MonitoredDevice
// contains filtered or unexported methods
}
Monitor represents an outlet that can track its energy usage
Click to show internal directories.
Click to hide internal directories.